#
# spec file for package google-sap-agent
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%global provider        github
%global provider_tld    com
%global project         GoogleCloudPlatform
%global repo            sapagent
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}

Name:           google-cloud-sap-agent
Version:        3.8
Release:        150100.3.50.1
Summary:        Google Cloud for SAP
License:        Apache-2.0
Group:          System/Daemons
URL:            https://%{provider_prefix}
Source0:        %{repo}-v%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) = 1.24
# PATCH-FIX-UPSTREAM - Fix unexpected memory consumption during token parsing in golang.org/x/oauth2
Patch0:         CVE-2025-22868.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  golang-packaging
BuildRequires:  pkgconfig(systemd)
%{?systemd_requires}
%if 0%{?suse_version} && 0%{?suse_version} == 1220
%define systemd_prefix /lib
%else
%define systemd_prefix /usr/lib
%endif


%{go_nostrip}
%{go_provides}

%description
Google Cloud SAP agent. Agent for GCE instances running SAP workloads.

%prep
%setup -q -n sapagent-v%{version}
%setup -T -D -a 1 -n sapagent-v%{version}
pushd vendor/golang.org/x/oauth2
%patch -P0 -p1
popd

%build
%goprep %{import_path}
pushd cmd
go build -buildmode=pie -mod=vendor -o google_cloud_sap_agent
popd

%install
install -d %{buildroot}%{_bindir}
install -d %{buildroot}%{systemd_prefix}/systemd/system
install -d %{buildroot}%{_datadir}/google-cloud-sap-agent
install -p -m 0755 %{_builddir}/sapagent-v%{version}/cmd/google_cloud_sap_agent %{buildroot}%{_bindir}
install -p -m 0622 build/google-cloud-sap-agent.service %{buildroot}%{systemd_prefix}/systemd/system
install -p -Dm 0644 build/configuration.json %{buildroot}%{_sysconfdir}/%{name}/configuration.json

%pre
%service_add_pre google-cloud-sap-agent.service

%preun
%service_del_preun google-cloud-sap-agent.service

%post
%service_add_post google-cloud-sap-agent.service

%postun
%service_del_postun google-cloud-sap-agent.service


%files
%defattr(0644,root,root,0755)
%dir %{_sysconfdir}/%{name}
%config(noreplace) %attr(0644,root,root) %{_sysconfdir}/%{name}/configuration.json
%license LICENSE
%{_datadir}/google-cloud-sap-agent
%attr(0755,root,root) %{_bindir}/*
%{systemd_prefix}/systemd/system/google-cloud-sap-agent.service

%changelog
* Tue Jun 10 2025 adrian.glaubitz@suse.com
- Update to version 3.8 (bsc#1244324, bsc#1244295)
  * Remove parsing of Pacemaker attribute is_ccm
  * Update spec file to remove GCBDR packages
  * Internal cleanup
  * Send agent status to WLM DW with WriteInsight()
  * Adds upcoming maintenance events chart and table to the maintenance system events dashboard
  * Fix Backint log_to_cloud configuration parameter
  * Update list of process metrics and hanamonitoring
  * Added Usage metrics to support bundle tool.
  * Enhance Support bundle collection
  * Updates to the maintenance dashboard with instructions on setup in the README.md
  * Update metric override file with new metrics marked for v3.8.
  * Dashboard updates
  * Add unit tests for gcealpha.go
  * Add unit tests for restore.go, remove unreachable code
  * Add unit tests for versionhandler
  * Outputting the agent status as a JSON string so it can be queried and parsed Log Analytics
  * Add usagemetrics for remaining OTEs
  * Increase coverage to > 90%% in processmetrics/networkstats test
  * Increase coverage to > 90%% in processmetrics/hanavolume test
  * Add unit tests for hanabackup
  * Added Test Case for GCE Service Creation Failure in Remote Validation Onetime Execution.
  * Internal change
  * Update below parameters in google-x4.conf file
  * Add Hana Monitoring metrics:
  * Add Hana log disk utilisation metric (in Kb)
  * Add Linux os metrics as part of process metrics
  * Make the bare metal metric resource type non-generic
  * Update TODO
  * Check the status of the WLM Data Warehouse API before starting metric collection.
  * Fix data race in status test
  * Make the bare metal metric resource type non-generic
  * Add WLM metric collection for SELinux config settings.
  * Adding the kernel version to the SAP System discovery data.
  * Collect SAP events in support bundle.
  * Adding support to collect hana monitoring metrics.
  * Auto updated compiled protocol buffers
  * Add Pacemaker WLM metrics: ASCS_IP, ERS_IP, ASCS_VIRTUAL_IP, ERS_VIRTUAL_IP
  * Add WLM metric collection for kernel version.
  * Fix github build failures.
  * Update Go version in build to 1.24.2.
  * Collect Status in daemon mode
  * Status OTE agent changes to use artifact registry list version
  * Add support for /var/log/messages collection including rolled over messages
  * Added timezone handling logic for querying process metrics
  * Add WLM metric: CLUSTER_HEALTHY for pacemaker
  * Collection definition test improvements.
  * Added support to collect pacemaker log files
  * Default Pacemaker PCMK fields to empty string.
  * Use correct destination folder in collectProcessMetrics
  * Ignore timestamps in test
  * Update process metrics query to use timestamp, before and after duration.
  * Add functionality to collect process metrics
  * Update SAP guest actions to utilize shared library
  * Update SAP Agent logusage command help message
  * Changes to the github action if commit/push of generated protos fails
  * Fix a couple of comments.
  * Adding support for collecting SapDiscovery logs from cloud logging.
  * Cleanup agentmetrics_test.go
  * Proto change
- Adjust upstream source paths in spec file
- Bump Go ABI version to 1.24 in BuildRequires
* Mon Apr 14 2025 adrian.glaubitz@suse.com
- Add -buildmode=pie to go build command line (bsc#1239946)
* Thu Apr  3 2025 rjschwei@suse.com
- Update to version v3.7: (bsc#1238831, bsc#1238833)
  * No public description
  * Moving CG disk validation to CheckPreConditions
  * Fix issue with filling in ha_hosts in HANA systems
  * Use updated UAP method for Guest Actions
  * Fix grep command used for landscape ID discovery
  * Correct arguments used by HANA disk discovery.
  * Add tagged disks to discovery data sent to Data Warehouse
  * Identify disks by mount point in SAP System data.
  * Auto updated compiled protocol buffers
  * Add collection for WLM Pacemaker alias IP setting.
  * Add the Maintenance Events Sample Dashboard
  * Auto updated compiled protocol buffers
  * Remove obsolete events proto from sapagent
  * Auto updated compiled protocol buffers
  * Add collection for WLM Pacemaker health check and internal load balancer metrics.
  * Auto updated compiled protocol buffers
  * Add collection for WLM Pacemaker SAPInstance automatic recover and monitor settings.
  * Remove restart logic used in configure OTE. Rely on config poller.
  * fixing TypedValue
  * migrating from the platform integration/common/shared to sharedlibraries
  * Default topology to SCALE_UP for non-HANA DBs.
  * Remove restarting from guestactions
* Tue Mar 11 2025 adrian.glaubitz@suse.com
- Add patch to fix unexpected memory consumption during token
  parsing in golang.org/x/oauth2 (bsc#1239197, CVE-2025-22868)
  * CVE-2025-22868.patch
* Wed Feb  5 2025 rjschwei@suse.com
- Update to version v3.6:
  * Removing experimental check. Enable config poller by default.
  * removing the experimental check from role based awareness in HANA Monitoring
  * adding oldest_backup_catalog_data_queries in HANA Monitoring
  * added backup_catalog_size_queries to HANA Monitoring
  * adding latest_log_backup_queries in HANA Monitoring
  * adding data backup duration queries
  * adding data backup log catalog queries
  * adding backups/log/catalog metric in HANA Monitoring
  * running the proto compile on push
  * only building and submitting protocol buffers when .proto files are modified
  * Auto updated compiled protocol buffers
  * fixes the build failure notifications, forcing a proto compile on this submit, will update with paths after
  * compiling protos on submit, removes the need for a submodule doring normal github clone and build
  * Add collection for whether UEFI is enabled on the OS.
  * fix panic in HANA Monitoring when Role based awareness is invoked
  * Moving references to the sharedproto dir
  * Add collection for WLM Pacemaker SAP HANA failover settings.
  * Add collection for WLM Pacemaker SAP HANA topology attributes.
  * Fix bug in parsing of Pacemaker XML resource clone tags.
  * Don't return before having a chance to discover non HANA DBs
  * Set "min_version" for Pacemaker metrics newly added for v3.7.
  * Add db type and host info to app discovery to support discovery of non HANA dbs
  * Add collection for WLM Pacemaker SAP HANA monitor metrics.
  * Read HANA landscape ID from nameserver.ini
  * Enable DR reconciliation for new SAP Agent builds
  * Fix for number of lines for CheckTopology
  * Add collection for WLM Pacemaker SAP HANA Topology start/stop timeout metrics.
  * Add a check to verify if disk names with specified prefix already exist
  * Update backup and restore logic for scaleout setup
  * Add support for restoration of disks in scaleout systems
  * Adding support for backing up disks for scaleout systems.
  * Use TimeoutSec for all command executions in configureinstance subcommand
  * Remove configureinstance overrideVersion parameter
  * allow query overrides to modify RunOn field for a query in HANA Monitoring
  * Adding new Backint config parameters to the agent status report
  * fixes issue where the windows service delete can hang  until the session is closed
  * Rename status name to Workload Manager Evaluation
  * Add object retention optional parameter to Backint - Agent for SAP
  * Update HANA Disk Restore functions to use revised interface methods.
  * Using temporary attachDisk interface instead of old interface
  * Add IAM tests for backint, wlm metrics, system discovery and disk snapshot
  * Add reference links to status ote
  * Fix race condition causing flaky unit test.
  * Change labels var name from "l" to "labels".
  * Explicitly specify default empty string values for new Pacemaker metrics.
  * Adds the winservice OTE and fixes the windows install / uninstall
  * Add functional checks for system discovery status ote.
  * Move configurablemetrics package into shared repository.
  * sap/nw/instance/role metric fix for SAP NW Java
  * Update HANA HA availability metric to account for DR setups.
  * DR discovery
  * Adds "-compact" flag to status ote for less verbose output.
  * Remove extra labels from reliability query
  * adds a replace for the submodule common code
  * Add functional checks for Hostmetrics, Processmetrics and Hanamonitoring in Status OTE
  * updates the go.mod and go.sum for platform changes
  * Compiles the platform and sapagent protos together
  * Adds the workloadagentplatform as a submoduile
  * Correct process names used for Netweaver Role identification
  * Add the functionality to provide the new disk prefix for group snapshot.
  * Add utility modules for sapagent IAM permissions
  * Add WLM collection for Pacemaker ERS metrics.
  * Update go.mod and sum
  * No public description
  * Move shared packages and protos from sapagent to workloadagentplatform
  * adding the handling for auth errors in case of connection retrial loop in hana monitoring
  * Add instance_name to labels for live migration metric event
  * Add log level functionality to metric events.
  * Add the IAM package with permission checking functionalities for checking permissions on GCP Project, Buckets, Secrets, and Disk
  * adding collection logic for Pacemkaer HANA clone attributes
  * Fix discovering virtual hostname for instances
  * Implements API scope full access check for Status OTE
  * SAP Events - Prepend full URL for availability metrics
  * Functional checks for Backint in Status OTE
  * Add Backint config value parsing/printing to Status OTE
  * adding WLM pacemaker stonith cluster property metric collection
  * adding WLM metric collection for OP timeout
  * Add Insight type for torso workload validation.
  * Add Insight type for torso workload validation.
  * Status OTE make service status a "State" type rather than bool.
  * ConfigureInstance - update SAPTune re-apply logic to support multiple solutions
  * Add agent health metrics to iam-permissions.yaml
  * adding retrials for connecting to databases till all are submitted in workerpool
  * Add network and subnetwork discovery to SAP System discovery process.
  * Add instance_name label to process metrics
  * Fix formatting in some log messages
  * only notifying on build failure for main branch
  * Add IAM Audit yaml that lists IAM permissions for various agent functionalities
  * Order labels in metric events
  * adding a separate check for HANA DB instances not defined in HANA Monitoring Configuration
  * Use the common rest package in instantsnapshotgroup
  * Add support for event overview and analysis to aianalyze.
  * Fix log message
  * updates to the build process
  * Only print denied/error IAM permissions in status ote
  * Fix enqueue_server WLM metric collection.
  * Status OTE switch IAM "role" to "permission"
  * Buffer metric event writes to group similar paths and reduce bloat
  * Add ASCS metrics to WLM collection definition.
  * Adding helpers and for aianalyze
  * Adding helpers and for aianalyze
  * Fix status OTE commandlineexecutor
  * Configuration validation in status OTE
  * Move sapagent GCS storage logic to shared
  * Add support analyzer one time command.
  * internal change
  * Ensure that performancediagnosticshandler_test will run quickly
  * copy /var/log/messages to support bundle
  * Change status proto `fullyfunctional` from bool to state enum
  * Get available version and systemd info in Status OTE
  * Add testable commandlineexecutor to supportbundle and performancediagnostics to address github test waits
  * Add WLM Pacemaker metric collection category for ASCS metrics.
  * Config validation in Status OTE
  * updates the github action notify
  * Bump sapagent version to 3.7.
  * Add ping functionality for hdbuserstore connections in databaseconnector
  * Remove assumption of package name and repo name being the same for getting latest agent version status
  * Add extra checks around file not existing in configureinstance
  * Add more states to bools in status OTE
  * Update the link to the next steps for HANA restore from disk snapshot.
  * Improvements to Pacemaker metrics tests.
  * Add identifier to netweaver availability
  * Simplify Workload Manager Pacemaker tests.
  * Add proper labels for availability SAP Events.
  * Add collection for WLM Pacemaker metric `gcpstonith`.
  * Add logging to cloudmetricreader and fix typo in configurationmetricreader
  * Skeleton code and agent status checks for status OTE
  * Configureinstance parameter name fix
  * Configureinstance parameter name fix for backport
  * MultipartUpload OTE
  * Add helpers for agent installation and service status
  * Improved error handling for GCE operations
* Fri Oct 18 2024 adrian.glaubitz@suse.com
- Update to version 3.6 (bsc#1231426, bsc#1231758)
  * Delete stale instant snapshot groups
  * Add collection for WLM Pacemaker metric `gcpstonith`.
  * Increase max retries for instant snapshot group to 8 from 3.
  * Fix fatih/color github package
  * PrintServiceStatus added to statushelper
  * Update generated proto files using protoc-gen-go v1.35.1.
  * adding set defaults method in instancemetadata
  * Fix ASCS discovery to handle commented lines and non-hostname values
  * Improve command used for HANA Version discovery
  * Add mutex to uap.go to prevent race condition.
  * Status OTE proto
  * Fix metrics sending for Backint
  * Update version OTE to print the version in the same format used by RPM
  * Add debug logs for HANA version discovery
  * Add a flag to indicate if an instance is part of a DR site.
  * Minor deleteISG changes
  * Add max retries to ISG service for exponential backoffs
  * update disk restore command param names and usage string
  * Change send-status-to-monitoring to send-metrics-to-monitoring to match flag name in usage string
  * Add additional error string to help debugging when metadata server call fails
  * Changing default naming of group snapshot to match mentioned format in flags.
  * Add usage examples for hanadiskbackup and hanadiskrestore
  * Add a log message to indicate that the HANA snapshot has been marked as SUCCESSFUL.
  * Implement module skeleton file layout for status helper for status check OTE
  * Add token scope for WIF authentication for ISG APIs
  * Lower the log level from INFO to DEBUG for messages generated by
    cloudmonitoring.sendBatch() to reduce log spam and prevent /var/log from filling up.
  * Add pagination support for instant snapshots
  * adding snapshot state metric in HANA Monitoring
  * Add scope for non-SA based authentication for XML multipart uploads
  * Set default values for configureinstance.
  * Only close the cloud logging client if the main thread exits
  * Add RHEL specific configurations for X4 to configureinstance
  * Improve backoff retries and error handling for ISG APIs
  * Convert instant snapshot to archive or standard snapshot based on -snapshot-type value.
  * Add usage metrics for hana insights OTE
  * Generate snapshot name in validate parameters if not provided by user
  * Remove concurrency when converting instant snapshots to standard snapshot
  * added the config poller in startdaemon
  * Add usagemetrics for gcbdr discovery OTE
  * Add debug logs to convertISGtoSS
  * Add usage metrics for HANA disk backup and restore
  * Add usagemetrics for gcbdr backup OTE
  * Fix Guest Actions integration test - Update performance diagnostics error message
  * Add pagination support for ListSnapshots
  * Update instantsnapshotgroup package for prod changes
  * Fix issues with HANA disk backup
  * Change error logs to warning logs for retries. We error once retries are exhausted. Some typo fixes.
  * Fix standard snapshot naming when converting from instant snapshot
  * Change error to warning for metadata server during retries
  * Fix a race condition in stripeddisk.go
  * Add cloud project to the usage metrics exclusion list
  * Fix bugs in striped disk backup
  * pull the necessary changes for 3.5 patch
  * Fix striped disk restore workflow
  * Remove deprecated reliability metrics settings from configuration
  * Modify hanadiskbackup for support for group snapshot workflow.
  * Add kernel change to 3.5 version of configureinstance
  * Add RHEL specific configurations for X4 to configureinstance
  * updating the typo in hananmonitoring.go
  * Modify support for group snapshot backup workflow
  * Refactor hanadiskbackup tests into separate striped and nonstriped tests
  * Modify hanadiskrestore package for support for groupsnapshot
  * Add support for group snapshots in HANA disk restore.
  * Refactor hanadiskrestore tests into separate nonstriped and striped disk tests
  * updating data backup state query to use state_name as metric and treating backup_id as a label
  * Refactor hanadiskbackup and hanadiskrestore to separate
    striped and nonstriped disk logic into separate files.
  * Change the order of kernel.migration_timer in google-x4.conf
  * Disable kernel migration timer to improve single flow network performance.
  * Add kernel.migration_timer = 0 to tuned.conf
  * Fix argument order mismatch.
  * Not creating a subdir for OTE logs by default
  * Fix LVM rename for restore from group snapshot
  * sending default metric in case SAP Control is not working in netweaver.go
  * Add old disk to CG after restore from group snapshot failed
  * Remove deprecated onetime logging methods
  * Change replication exit status in some primary error scenarios
  * Add region and subnet to URI for IP calls to improve resource discovery.
  * Fix default snapshot name generation
  * Update performancediagnostics OTE to use the Run pattern with runOpts and oteLogger
  * Change log level for netweaver collector retry to debug
  * Add method for setting up One Time Execution logs
  * updated data_backup_state_queries with entry type label
  * added guest action handler for instancemetadata
  * Fix configureinstance command to print diffs to console
  * Fix bug in version command where it wasn't printing to console.
  * Update reliability OTE to use the Run pattern with runOpts and oteLogger
  * Add RHEL specific configurations for X4 to configureinstance
  * add os version and vendor information to instancemetadata
  * Use the same disk type as the original disk for staginghanadiskrestore
  * Update migratehmadashboards OTE to use the Run pattern with runOpts and oteLogger
  * Add newly attached disks to consistency group after restore
  * removing unnecessary test files after refactor setOSReleaseInfo function
  * refactor osReleaseInfo function move it to utils
  * Fix log message in supportbundle to show the correct zip file location.
  * Update systemdiscovery OTE to use the Run pattern with runOpts and oteLogger
  * Bump SAP Agent version to 3.6
  * Add 3.5 to configureinstance versioning
  * Update service OTE to use the Run pattern with runOpts and oteLogger
  * Update hanadiskrestore OTE to use the Run pattern with runOpts and oteLogger
  * Add timeoutSec parameter to configureinstance
  * Add confirm-data-snapshot-after-create functionality for striped disk
  * Add ISG deletion and ISG label to standard snapshot
  * Add staging support for ISGs in staging OTEs
  * Add optional parameters for hana compute metrics report to performance diagnostics.
  * Update migratehanamonitoring OTE to use the Run pattern with runOpts and oteLogger
  * Update staginghanadiskbackup OTE to use the Run pattern with runOpts and oteLogger
  * Update instancemetadata OTE to use the Run pattern with runOpts and oteLogger
  * Update validate OTE to use the Run pattern with runOpts and oteLogger
  * Update staginghanadiskrestore OTE to use the Run pattern with runOpts and oteLogger
  * Update gcbdrbackup OTE to use the Run pattern with runOpts and oteLogger
  * Update hanainsights OTE to use the Run pattern with runOpts
  * Update installbackint OTE to use the Run pattern with runOpts and oteLogger
  * Update balanceirq OTE to use the Run pattern with runOpts and oteLogger
  * Update configureinstance OTE to use oteLogger
  * Add java_proto_library for sapagent apis.
  * Remove previous placeholders for ISG APIs
  * Add initial layout for staging OTEs for hanadiskbackup and hanadiskrestore
  * Remove memory address logs and improve log messages in performancediagnostics.
  * Add support for setting custom_time to UTCNow+<INT>d in Backint.
  * Update readmetrics OTE to use the Run pattern with runOpts and oteLogger
  * Refactor the rest of the OTEs to seperate OTE and Daemon mode invocations
  * bumping up cloud.google.com/go/monitoring to v1.20.3
  * No public description
  * adding an OTE for fetching instance metadata
  * Automated Code Change
  * Add datapol annotations to hanamonitoringmigration.proto
  * Replace duplicate type declaration in hanadiskbackup and
    hanadiskrestore OTEs with a single reference from onetime.
  * Refactor timeseries package to use a struct instead of proto for cloud properties.
  * Update configure OTE to use onetime RunOptions and OTELogger
  * Add unit test to cover context cancellation in performancediagnostics.
* Mon Aug 26 2024 adrian.glaubitz@suse.com
- Update to version 3.5 (bsc#1229668, bsc#1229669)
  * Add instance properties to all components based on instance role.
  * Refactor OTEs hanadiskbackup and supportbundle to enable different
    execution params for internal and user invocations - 2/n.
  * Backport the configureinstance increased timeout to 3.4 and 3.3
  * Perform general X4 configurations first, then OS specific
  * Log the copy error only to log file and not to console
  * Add unit test to cover `gce.New` in systemdiscovery.
  * Adding IFNULL to log backup queries
  * Add HANA Compute Resources Report to performancediagnostics bundle.
  * Add mutex for backint event annotation logging
  * Only wait for shutdown in the initial start routine. Continue on during restarts.
  * Update backint log message for event annotations
  * Create HANA compute metrics report to add it to performancediagnostics.
  * Correct SAP System proto merging.
  * Change SAP_BACKINT_FILE_TRANSFER invocation
  * Adding proto for instance metadata OTE for wlm service
  * Report host maintenance events to Cloud Monitoring as part of ProcessMetrics
    data collection. Collection is done by querying the local metadata server.
    https://cloud.google.com/compute/docs/instances/host-maintenance-overview
  * Remove flaky unit test for canceled context in performancediagnostics.
  * Update startdaemon so LogRunningDaily and waitForShutdown
    behave as expected during configuration restarts.
  * Improve detection of Netweaver role to include SID check for multi-instance nodes.
  * App servers are no longer responsible for reporting DB scale type
  * Refactor computeresources to collect time-series disk
    IOPS usage metrics for performancediagnostics.
  * Fix typo in service_linux.go
  * Add SAP Workload Actions for start, stop, snooze.
  * Refactor OTEs hanadiskbackup and supportbundle to enable different
    execution params for internal and user invocations.
  * Add usage metrics for guest actions
  * Refactor computeresources to collect time-series
    Memory usage metrics for performancediagnostics.
  * Refactor DB node discovery to use sapcontrol.
  * Restart daemon services when a guest action requires a restart.
  * Add WLM metrics for HANA delta and snapshot backups.
  * Add retry options for parallel restore.
  * Internal Change.
  * Add support for "UTCNow" as a value for the custom_time field in the Backint
    configuration. This will set the customTime metadata entry to the current time
    in UTC.
  * Configureinstance don't fail process if backup file failed
  * Add validation for HANA database metrics configuration.
  * Add queries for disk read/write time
  * Refactor computeresources to collect time-series CPU
    usage metrics for performancediagnostics.
  * Introducing sleep to let symlinks for the new disk to be created.
  * Add new metrics to default queries for HANAMonitoring
  * Fix HANA HA availability and replication metrics for error scenarios.
  * Add combinations of roles to InstanceRole enum.
  * Add condition to throw error when compression is used along with:
  * Adds a "service" OTE to enable and disable the systemd service
  * Guest actions support for backint OTE
  * Add explicit formatting to Backint logs with rounding.
  * Balanceirq updates.
  * Add usage metric for Backint recovery parameter enabled
  * Add metric events for SAP service metrics.
  * Making the next to last section of usage metrics generic
  * Guest action handler for gcbdr-backup operations
  * Properly merge Workload properties in SAP System details.
  * Fix a log message format in configuration.go file.
  * Add logpurge support in gcbdr-backup OTE
  * Merge instance properties when merging discovered SAP apps
  * Add additional test cases to guest actions integration test
  * Adding package, os processes and systemd services information to support bundle
  * Ensure instance numbers are a 2-digit zero-padded number
  * Add logbackup handler in gcbdr-backup OTE
  * Increase timeout for configureinstance saptune commands to 300 seconds.
  * Fix context cancellation in process metrics
  * Update systemd setting to allow access to /etc configurations via guest actions
  * Execute freeze script in gcbdr-backup OTE via sidAdm
  * Add support for unfreeze operation in gcbdr-backup
  * Bump SAP Agent version to 3.5
  * Fix metrics and database discovery for NW Java systems
  * Expand regex for SAP Services identification to handle other possibilities.
  * Add Metric Event Logging for remaining metrics
  * Remove doc comment about usagemetrics Error statuses being reported once per day.
  * Add checks in onetime to prevent log-path from being a directory.
  * Update config logic and disable WLM for systemdiscovery OTE.
  * Changes to permissions for Agent's log dir and log-path overrides for OTE
  * Check for execute permission for /usr/sap directory before discovering SAP applications.
  * Add `context.cancelFunc()` to exit in case of any error while reading.
  * Fetch HANA processes in performance diagnostics computeData through computeresources package.
  * Add support for freeze operation in gcbdr-backup
  * Fix logging in netweaver collector
  * Ordering the subcommands in ascending Name order for help,
    added an additional newline after the version print
  * metricevents - Make AddEvent thread safe and add event logging for metrics
  * Integrate SystemDiscovery OTE into PerformanceDiagnostics OTE.
  * Initialize GCBDR-Backup OTE to execute prepare script
  * Add Usagemetrics for hdbuserstore key usage
  * Minor log change in backint
  * Add log to Backint for querying for file transfers.
  * Expand HANA replication configuration reading functionality.
  * Shorten Backint dashboard scorecard titles.
  * Add /etc/google-cloud-sap-agent to ReadWritePaths
  * Updates to uap backoff parameters
  * Add metricevents to track state changes of specific metrics.
  * Add guest action support for configure instance
  * Fix error handling in fillWorkerBuffer() and add encryption support for parallel restore.
  * Add a new configuration parameter `parallel_recovery_streams` to enable parallel restore.
  * Add guest actions support for gcbdr-discovery
  * Initialize Discovery object in SystemDiscovery OTE handler.
* Fri Jun 28 2024 adrian.glaubitz@suse.com
- Update to version 3.4 (bsc#1227134, bsc#1227135)
  * Adding project to exclusion list
  * Add machine type to configure instance proto for WLM metric collection.
  * Add test channel for Guest Actions. Make default channel the registered channel.
  * Set backup object's customTime field as part of backint backups
  * Add workload discovery to configure command
  * Add multiple workers support in parallelreader for parallel downloading during restore.
  * `configureinstance` with `overrideVersion` set should log a warning and continue.
  * Minor log change in balanceirq
  * Add common function to parse parameters for guest action handlers
  * BalanceIRQ OTE added to Agent for SAP
  * Remove output from stdout for DIAGNOSE
  * Small hyperThreading change for configureinstance
  * Add initial steps to initialize the SystemDiscovery OTE in IIOTE and command mode.
  * Adding single worker support in parallelreader for download.
  * Read encryption key from file if specified in parameters file
  * Run configureinstance OTE only on supported instances during WLM metric collection.
  * Add instance ID to user agent string for SAP Agent.
  * Return `UsageError` as exit status instead of `Failure` in case of invalid parameters
  * Bumping up the agent version
  * Use json marshalling instead of manually parsing from map in configure handler
  * Move metric override modules to metricoverrides.go for general use
  * Updating the gcbdr proto
  * Updating param names to make it more clear in performance diagnostics
  * Add DiskSizeGb to Disk for disk creation.
  * Add Demo Metrics for Process Metrics
  * Add warning message for configureinstance overrideVersion
  * Add 3.3 to configureinstance versioning
  * Fix log message in configureinstance
  * Rename scope and param file to type and backint-param-file to avoid confusion
  * Add new OTE structure for SystemDiscovery.
  * Allows SAP system data to be read from an override file instead
    of discovered from the system. Useful for testing.
  * Refactor buildSupportBundleCommand by marshalling command parameters
  * Remove cluster member check for cluster collection
  * Add connectParameters as a function parameter in restoreFile function to have
    multiple bucket handles in parallelreader for parallel downloading.
  * Enable auto discovery of disks and make datadiskname and zone optional parameters
  * Add support for performancediagnostics OTE guest action handler
  * Add override version flag to configureinstance
  * Rename LVM volume group of restored disk to that of the target disk.
  * Sleep during TestCommunicateWithUAP to only execute intended
    code path once instead of many times.
  * Update grub configuration for X4 configureinstance
  * Extend result-bucket support to support bundle guest action
  * Add provisioned-iops and provisioned-throughput labels
    to snapshots and extract them during restore.
  * Configureinstance updates for SAP ECS
  * Add sequential in parallel download functionality for restore to SAP Agent.
  * Implement hanadiskbackup guest action handler
  * Add operation_id to UAP status labels.
  * Add user agent overrides for cloud monitoring
  * Updating generated protobufs
  * Update sanity check for fast collector metric
  * Reliability Metrics - Use the usage metrics instead of
    internal cloud monitoring metrics
  * Fix restoreFromGroupSnapshot and restoreFromSingleSnapshot logic
  * Implement support bundle handler. This CL follows a pattern for
    implementing handler which was developed in cl/636640791
  * Move timeseries.go and cloudmonitoring.go to shared/
  * Only stop HANA monitoring if successive errors are auth related
  * Use flag names for command parameters in configureHandler
  * Add check and apply finished metrics to configureinstance
  * Add snapshot / group backup name to success log message
  * Better handling of experimental flag in hanamonitoring
  * Return error if physical device is empty
  * Added an experiemntal flag to control role based awareness in hana monitoring
  * Adding role based awareness logic in HANA Monitoring
  * Add upload feature to support bundle
  * Add context to onetime logging functions
  * Fix logging and make confirm-data-snapshot-after-create true by default
  * Add debug logs for hanabackup to help troubleshoot issues.
  * Remove HDB User requirement when HDBUserstore key is passed for hanadiskbackup
  * Append labels to detached disk in hanadiskrestore
  * Add placeholder for parallel reader in Backint
  * Modify restore handlers to be able to restore from either
    source snapshot or group snapshot.
  * Modify checking preconditions and adding fakes for group snapshot restore.
  * Add initial support for restoring from group snapshot.
  * Add UAP Communication to startdaemon (gated by a configuration).
  * Fixing the commands in perfdiag
  * Refactor handleAgentCommand with guestActionsHandlers map
  * Add replication sites to system component proto
  * Build updated to use -mod=vendor during build
  * Updated go.mod and go.sum with dependencies for safetext,
    using go mod vendor for github action
  * Adding changes for target based config in hana monitoring
  * Overriding the user agent for Cloud Logging API calls
  * Fix typo in guestactions.proto
  * WLM Hana Full Backup Validation Metric collection
  * Add configure command to guest actions. Establish how the new proto
    format will be used in message handling.
  * Add ping check to HANA monitoring
  * [commandlineexecutor] Add the ability to directly pass data into Stdin, avoiding
    the need for intermediary piping commands, such as "echo 'data' | my_app".
* Fri May 31 2024 adrian.glaubitz@suse.com
- Update to version 3.3 (bsc#1225166, bsc#1225558)
  * Build updated to use -mod=vendor during build
  * Updated go.mod and go.sum with dependencies for safetext,
    using go mod vendor for github action
  * Add actual values and comments to usagemetrics.go to ensure that
    error and action codes are only appended to the end of the list.
  * Remove usage metrics from configureinstance.go
  * Add a hard Disable for reliability metrics collection
    until the namespace is created and tested.
  * Adding metrics for time taken by each query
  * Add SHA224 of labels as a new label.
  * Remove collect_reliability_metrics from configuration.json
  * Small tweaks to backint log and inquire path generation
  * Fix for unmarshalling backint configuration.
  * Implementation of instant snapshot group backup workflow
  * Backint changes around shorten_folder_path
  * Rename max_diagnose_size_gb to diagnose_file_max_size_gb
  * Adding start and finish logs in performance diagnostics
  * Validate that all disks mapped to /hana/data belong to the same consistency group.
  * Rename backint monitoring metrics parameter
  * Trim folder prefix for Backint INQUIRE output.
  * Add the ability to test the database connection
  * Reduce log level of some storage messages to debug.
  * Finalize guest action request and response format.
  * Backint dashboard fix logs
  * Add scorecards to backint dashboard
  * Making proto changes for HANA Monitoring support
    for multiple tennats and ha setup
  * Add total upload/download time to log.
  * Add HANA indexserver.ini metrics to WLM metric collection.
  * Add Netweaver role metrics as part of process metrics
  * Rotate old support bundles.
  * Update the default value of confirm-data-snapshot-after-create
    to false. and add to usage()
  * Add option to confirm HANA snapshot as successful before disk snapshot is uploaded.
  * Change log level from warn to info for non-critical messages.
  * Add diagnose_folder parameter to Backint
  * Add a 1 GB buffer to needed bytes for diagnostic
  * Add labels to group snapshot backup.
  * Enable the show status and restart agent functions for Windows.
  * Add WLM metric collection for num_completion_queues and num_submit_queues.
  * Collect support bundle on Backint errors.
  * Adding usage metrics to performance diagnostics
  * Collect agent-only support bundle on failure of backint and hanadiskbackup.
  * Minor Backint improvements
  * Add ability collect only agent logs using agent-logs-only flag to supportbundle
  * Bump version to 3.3
  * Add Backint metrics dashboard
  * DO NOT remove log files on uninstall
  * Adding more unit tests
  * Changing location of zipped file to within the
    final folder identified by unique timestamp.
  * Minor refactorings and improvements with increasing code coverage
  * Make sure DB instance number is recorded in System data.
  * Change configuration.json to 0664 to ensure world cannot write.
  * Add Netweaver Java discovery to SAP Agent.
  * Add a new version of functions to read cloud properties from metadata server.
  * Updating generated protos to proc-gen-go v1.34.1
  * Updating runConfigureInstance method and adding unit tests
    for covering configure instance ote invocation
  * Zip the final bundle and add upload functionality
  * Record database SID alongside tenant DB SIDs
  * Reduce log severity in discovery
  * Add HANA version to product version data
  * Fix race condition in tests
  * Read disk mapping from instance info if source disk
    is not provided to hanadiskbackup
  * Add option to shorten the folder path in the bucket.
  * Add SSL support for cmdline-based querying and some bugfixes
  * Move recovery package to shared directory.
  * Update protoc-gen-go version to v1.34.0 in multiple protos
  * Adding FIO commands to performance diagnostics
  * Remove error logs when errors are being returned
  * Adding perfdiag to performance diagnostics
  * Add AppInstance data to discovery data uploads.
  * Introduce protos for guestactions messages and responses.
    Support multiple commands per message.
  * Update wording for HANA Insights rules.
  * Configureinstance updates.
  * Adding a check for retention policy before performing backup operation.
  * Remove the unused loglevel flag from logusage OTE
  * Change the language around the default parameters being
    optimized for performance in backint
  * Add instance role to SAP System properties
  * Increase wait time for index server to stop.
  * Integrating backint OTE into performancediagnostics
  * Update wording around configureinstance unsupported machine type.
  * Pass the right disk name to check if disk is attached
  * Integrating new DB Handle and hdbuserstore key support
    with remaining HANA DB dependant workflows
  * Refactor HANA and filesystems specific code to a common hanabackup package
  * Bumps x/net dependency to v0.23
  * Append HANA Insights rule to WLM fake metrics file in script to generate WLM rule.
  * Integrating configure instance ote in performance diagnostics
  * Update disk backup OTE to parse paths even with /dev/mapper
    in the middle of path, not necessarily as a prefix
  * Adding a few missing labels to wlm-fake-metrics.yaml
  * Changing loglevel for onetime.Init() calls
  * Refactor change - Move PD related functions to gce.go
  * Fix agentcommunication import replace statements
  * Update replace functions for new open source dependencies.
  * Set up scaffolding for guest actions handling in SAP Agent along with UAP library code
  * Backint upload/download metrics sent to cloud monitoring.
  * Cleaning up the performance diagntics file wth recent changes
  * Fixes to usage strings in OTEs for optional params
  * Integrating new database connector with HANA Monitoring
    and adding support for HDBUserstore Key
  * Implement hdbsql commandline result parsing
  * SAP Discovery - Add SAP Instance Numbers to instance properties
  * Updating OTEs to include params for when OTE is invoked internally
  * Modifying flags to follow design changes
  * Create fake WLM metric overrides for testing
  * Implement constructors and query functions for querying
    HANA DB via hdbuserstore using cmdline
  * Skeleton for querying HANA DB via hdbuserstore using cmdline
  * Parameterize Backint Diagnose max file size.
  * Metadata parameter added to Backint.
  * Adding initial layout for performance diagnostics OTE
  * Create a new API CreateClient() in shared logging which
    returns an error in case of failures
  * Backint no longer writes ERROR if temporary chunk failed to delete.
  * Create onetime.Init() to condense reused code.
  * Fixing a typo in a process metrics retry logic comment
  * Rename workload_validation param with workload_evaluation in configure OTE
  * Send agent version in Write Insight requests
  * Ensuring /sap/cluster/resources covers all the nodes.
* Wed Apr  3 2024 adrian.glaubitz@suse.com
- Update to version 3.2 (bsc#1222215, bsc#1222216)
  * Remove internal gensupport package.
  * Restore additional error handling and response checking to internal data warehouse client.
  * Updating the aggregate function in HANA insight rules
  * Remove a leftover debug log
  * Allow multipart uploads for PIPE file types.
  * Update go-hdb version to v1.8.0
  * Perform log restores in serial rather than parallel.
  * Add sample usage examples to commandlineexecutor
  * Small update to configureinstance OTE
  * Add nil check in backup and restore flows to protect against panics.
  * Close http response body in WriteInsight() and soap.go
  * Record topology type.
  * Initialize usagemetrics for OTEs
  * Add Instance Number to SAP System instance properties
  * Set `min_version` for WLM `os_settings` system metric.
  * Increase timeout for saptune re-apply commands.
  * Adding handling for encrypted snapshots in backup and restore
  * Change the version check comparisons to account for versions
    older than those listed in SAP Note.
  * Skip the Netweaver metrics that need dpmon on NW kernels
    affected by SAP Note: 3366597
  * Fix imports
  * No public description
  * Use internal data warehouse client.
  * Fix disp+work command invocation for Netweaver Kernel version discovery.
  * Add note about default parameter values to installbackint.
  * Add mutex in multipart writer for potential data races.
  * Update go.mod and go.sum
  * Skip XFS freeze by default unless user passes a parameter to do it explicitly
  * configureinstance minor updates.
  * Add safety check for usage metrics on BMS
  * Storage Class parameter added to Backint.
  * Update configureinstance's X4 saptune conf.
  * XML Multipart Write() and Close() methods completed.
  * Fixes the vmmanager policies for sles12 and sles15 used in the cloud console removes
    the individual cloud console policies and consolidates them into one Adds a general
    gcloud command line policy
  * Standardize logging for workloadmanager package.
  * Multipart XML API Uploads for Backint.
  * Add database system SID to database properties.
  * Fix NW HA node identification for RedHat deployments.
  * Add workload properties to discovery object returned by discoverSAPSystems
  * Add ASCS instance number to application data
  * Add Workload Manager validation rule for checking OS settings.
  * Enable WLM metric collection by default, disable submission of data to Cloud Monitoring.
  * Decoupling primary executable command and providing an alternative to lsof
  * Added HANA version in support bundle collection
  * Add WorkloadProperties to merged system details and to WLM Insights
  * Replace the link placeholder with the actual link
  * Add instance number to SAP discovery data
  * Tranche 12: HRE Rules
  * Minor typo fix in workloadmanager's hana metrics module
  * Add pacemaker metrics with SID labels to process metrics
  * updating the regex for backup and backint files to take care of log rotation in support bundle
  * Add support for disk snapshot labels for easy lifecycle management of snapshots
  * Added new OTE for changedisktype workflow
  * Add WorkloadProperties to SapSystemDetails for apps_discovery
  * Testing the timeseries in unit tests instead of just checking the count
  * Record Netweaver kernel version.
  * Tranche 12: HRE Rules
  * Testing the timeseries in unit tests instead of just checking the count
  * Testing the timeseries in unit tests instead of just checking the count
  * Relocating pacemaker collection related packages to internal/pacemaker
    for common use between process metrics and WLM
  * Use results from latest round of discovery for the collection of process metrics.
  * Handling zero rows returned case better in HANA insights
  * Adding docstrings to workloadmanager package
  * Adding docstring to configure OTE
  * adding docstrings to methods in support bundle
  * Add X4 specific configurations to configureinstance OTE.
  * Add helper functions to configureinstance OTE.
  * Display updates for HANA Insights WLM rules rollout.
  * configureinstance OTE
  * We expect the command to return a non-zero exit code and we should not be
    returning an error. Execute treats non-zero exit code as error.
  * Removing the sap control process command line params
  * Revert "Fixing system replication status code being returned"
  * configureinstance OTE
  * We expect the command to return a non-zero exit code and we should not be
    returning an error. Execute treats non-zero exit code as error.
  * Removing the sap control process command line params
  * Fixing system replication status code being returned
  * Wait for hdbindex server to stop after HANA is stopped
  * Log error to console in cases where LVM is not being used
  * Adding JournalCTL logs to support bunddle
  * hanadiskbckup - Add missing params to the Usage string
  * Move usagemetrics package into shared folder
  * Fixed data race error in TestCollectAndSendSlowMovingMetrics()
  * Disk backup/restore - Enable send-metrics-to-monitoring by default
* Tue Feb 20 2024 adrian.glaubitz@suse.com
- Update to version 3.1 (bsc#1220010, bsc#1220111)
  * Fixing system replication status code being returned
  * Reduce disk snapshot wait durations
  * Fix test flakes in workloadcollector test.
  * adding metrics for db freeze time and total workflow time
  * Fix for SAP System discovery adding the current host to all components.
  * Restore default WLM metric collection settings.
  * change description of validate OTE
  * fix a typo in the command name and add a delay before we try the unmount
  * Use underscore as separator for flags in place of hyphens
  * Enable host_metrics and disable reliability_metrics by default in configure OTE
  * Collect reliability metrics in the free namespace
  * Remove user from cmd params for HANA Replication
  * Enable workload manager metric collection by default.
  * Add support configuration flag to enable legacy WLM metric data submission workflow.
  * Lowers the log level of discovery to info
  * Fix for HANA Replication Config
  * Add additional instance-id parameter for users who do not want to provide port number
  * Use _ instead of - for parameters in configurebackint
  * Implementing panic recovery to HANA Monitoring: CreateWorkerPool
  * Fix issue with process metrics subroutine starting.
  * Add a flag to enable or disable workload discovery.
  * Reduce logs in sapdiscovery to debug, these are now run a
    lot more frequently and are flooding the logs
  * Use bucket `cloudsapdeploystaging` for staging environment.
  * Updates default value handling for system discovery flag.
  * Added default values to some frequency flags in configure OTE
  * force a sync before unmounting to clear out stale file handles
  * Retain recoverable routine in process metrics.
  * Ensures slow metrics workers stop on context cancellation.
  * Log lsof output if unmount fails during restore
  * SAP Discovery - Discover R3trans data
  * Add panic recovery to collectiondefinition update routine
  * configurebackint OTE.
  * Adding panic recovery to remote.go
  * Prevent host metrics from restarting the daily metrics report if it has already been started.
  * Add panic recovery to agent metrics
  * Implementing panic recovery for hana monitoring: logging action daily
  * Routines now use their own context and cancel in the event of a panic recovery.
  * Add panic recovery to host metrics routines
  * Removed -path flag and fixed usage string
  * Add workload properties to the SAP System definition.
  * Add panic recovery to collectMetricsFromConfig routines.
  * Add panic recovery to fast metric collection routine.
  * Reduces the log severity to debug for the exponential backoff policy
  * Add panic recovery to heartbeat routine.
  * Updating configuration.json file to remove deprecated sap_discovery field
  * Use protojson instead of custom function for snake_case marshaling
  * Add panic recovery to WLM metrics collection
  * HANA Insights rules tranche 11: Create unit tests and add to auto push
  * Add panic recovery to workload collector daily usage metrics.
  * Processmetrics - suppress Error and Warn logs that really need to be debug
  * Formatting the output of messages printed by configure OTE
  * Changing flag names of configure OTE to align better with configuration.json fields
  * Add automatic panic recovery to slow metrics collection
  * Add panic recovery to goroutine collectAndSend
  * Add panic recovery to goroutine
  * Retain recoverable routines beyond function scope.
  * Implement recovery handler for SAP System discovery package
  * Tranche 11: HRE Rules
  * Update github build
  * Adds generic panic recovery to SAP System discovery package
  * Initialize the sidadm env to ensure restore can be run as root user
  * not pacaking gcbdr scripts till launch of the feature
  * Change datatype of frequency flags from string to int
  * Breaking down --frequency flag into separate flags for different features for better isolation
  * Fix configuration.json file from being written in camelCase to snake_case
  * Tranche 6,7,8,9,10: HRE Rules
  * Suppress pacemaker related log from Error to Debug
  * creating the OTE for GCBDR discovery
  * Update HA node identification
  * Tranche 10: HRE Rules
  * Update file permissions and ownership for installbackint when running as root.
  * Adding newline after version print.
  * Exposing HANA Logical volumes availability metrics
  * Make workloadmanager parameters test more robust.
  * Fix panic in cloud discovery
  * Tranche 10: HRE Rules
  * Add recovery_folder_prefix parameter to Backint.
  * Mark process_metrics_send_frequency as deprecated
  * Add snapshot-type param to hanadiskbackup with default as STANDARD
    type. Users can override to ARCHIVE type if needed.
  * Add new folder_prefix parameter to Backint.
  * Add HANA new HANA insight rules to BUILD file and embed sources
  * Tranche 10a: HRE Rules
  * Tranche 6b: HRE Rules
  * Tranche 8b: HRE Rules
  * Fix for sending isABAP value
  * Updating logusage command line flags
* Thu Jan 25 2024 adrian.glaubitz@suse.com
- Update to version 3.0 (bsc#1218736, bsc#1218737)
  * Suppress packemaker command error to debug to avoid log flooding
  * Expand load balancing cluster discovery.
  * Log success messages in OTEs to STDOUT instead of STDERR used by log.Print
  * Use bash always to avoid variation of behavior across OS/Shell types
  * Minor updates to installbackint.
  * Backint compose step properly saves metadata.
  * Fix issue with discovery on ASCS instances.
  * hanadiskrestore - fix the format of disktype string for disk create API
  * Fix issue with PCS cluster address discovery.
  * Update transform to insight
  * Rename HANA backup/restore OTEs to reflect they are supported
    for all disks and not just persistent disk
  * Increase the timeout for HDB stop to account for busy DBs
  * Adding project sap-ecs-testing to the list.
  * PD Restore - Support provisioned-iops and provisioned-throughput
  * Integration test for configure OTE
  * Added precondition in hana pd backup for stripped LVM
  * Add a precondition check to verify user has passed a valid
    snapshot name that is present in the current project
  * Update the usage to reflect additional required param
  * Minor path update for supportbundle OTE.
  * Fixing bug in slow moving metrics partial collection scenarios
  * Adding check for agent status after restart.
  * Ensure Backint ComposeChunks has a valid bucket handle
  * Discover whether a Netweaver instance is ABAP or Java
  * Replace standard slices package with third party version
  * WLM HANA metric `ha_in_same_zone` now reports instance
    names for HA nodes in the same zone
  * Fix data race condition for Backint Backup with new client connections
  * Make -new-disk-name a required parameter to avoid the 63 char
    limit in the name length due to auto-generated names
  * Fix command for collecting Corosync metric `two_node_runtime`
  * Make snapshot name similar to disk name
  * Bump golang.org/x/crypto from 0.15.0 to 0.17.0
  * Enable Discovery config flag controls submission
    to Data Warehouse and Cloud Logging
  * Create new clients for each operation in Backint
  * Add `client_endpoint` to Backint proto.
  * Getting the build number into the version for display
  * Backint config name change: service_account to service_account_key
  * Add HANA HA metrics to collection definition.
  * Fix sorting bug in a diff in apps_discovery_test.go
  * Add discoverHANATenantDBs to main code path
  * Change PIPE filemode to WRONLY to allow us to detect broken pipes
  * Deprecate `sap_system_discovery` config field in favor of `enable_discovery`
  * Move the validation of whether user passed correct PD, before stopping HANA
  * Add a placeholder for public doc link with next steps
    after hanapdrestore workflow has completed
  * Fix executable path for HDB version command
  * Add optional param `new-disk-name` to hanapdrestore
    for users that wish to override the default
  * Sort the skipmetrics in unit test to avoid order related flakes
  * Generalizing configure OTE
  * Discover Netweaver kernel version
  * Fix Sprintf call
  * Use SAP System data to determine if HANA HA nodes share the same zone.
  * hanapdrestore - do not delete PDs in case of failures
  * Create discoverHANATenantDBs method to support multiple SIDs for HANA tenant DBs
  * Send additional fields in Data Warehouse WriteInsightRequest
  * Updating the username parameters for hana pd backup and restore
  * Retrieve Reliability data every 2 hours instead of 24
  * Discover HANA version
  * Fix import for GitHub build
  * Add instance properties, and topology information to system data
  * Keep the device nam and disk name same after restore
  * Move sapdiscovery package into system package
  * Changer the default name of the disk created by restore workflow
  * Updates the generated protobuf go for system.proto
  * Update generated system proto
  * Update go.yml
  * Add topology and instance properties info to SAP System data
  * Add a check to verify the disk is attached to instance, fail if disk is not attached
  * Add application and database software properties to system representation
  * Fix race condition in heartbeat test case
  * Add error handling to restore workflow to try and keep
    the HANA system in a clean state on failures
  * Enable LogToCloud by default for both OTE and Daemon modes
  * Bump Agent version to 3.0
  * Reliability OTE added to SAP Agent
  * Declare public Get interface for SAP System discovery data
  * Integration testing for Networkstats Package
  * Adding project sap-ecs-testing to the list
  * Adding one time execution for enabling/disabling of features
  * Change to using custom retries for initial bucket connection
  * Default collection definition to be fetched from GCS
  * Add a 2 minute context timeout for initial bucket connection
  * Add `collection_config_version` as a WLM system metric
  * Make project, host param optional for hanapdbackup,
    in addition make user param optional for hanapdrestore
  * Fix potential nil dereference WLM metrics collection
  * Add force-stop-hana to restore workflow to forcefully stop
    HANA when the param is passed
  * Rename the HANA PD snapshot and restore workflows
  * Add unit tests for GetProvisionIOps and GetProvisionedThoughput
  * Remove the TestCollect unit test which relies on nc
    command which can be flaky in unit tests
  * Increase Backint timeout for PIPE files to 3 minutes
  * Add XFS freeze and unfreeze to PD based snapshot
* Tue Nov 28 2023 adrian.glaubitz@suse.com
- Update to version 2.8 (bsc#1217373, bsc#1217374)
  * Bump agent version to 2.8 to support C3/M3 certification
  * Update go.yml to use go 1.21
  * Switch from "slices" to "go_exp.../slices" for go version dependency
  * Use newly refactored discovery packages.
  * Fixes issue with diskname from source or device name
  * Adds extreme disk type IOps and Throughput for host metrics
  * Add `INTEGRATION` target config environment for collection definition testing
  * Add project number to SAP System proto
  * Add a cache to discovered resources. This reduces the number of API
    calls needed to perform System Discovery
  * Replace windows wmic hardware queries with PowerShell wmi queries
  * Fix test flakiness
  * Improve development process for collection definition configuration
  * HANA PD based snapshot and restore - changes to add wait for uploading
  * Fix for kokoro build issue in processmetrics/networkstats
  * GCBDR SAPCoreAPP Package in Agent for SAP
  * Add version tracking for WLM validation config
  * Send workload validation config to remote instances for use during remote collection
  * Add flag for passing in workload validation config into remote collection OTE
  * Bump google.golang.org/grpc from 1.58.2 to 1.58.3
- from version 2.7
  * Added ote for hma dashboards migration
  * Increase Max backoff in storage package to 300 seconds
  * Added subpaths for collection of required TCP metrics
  * Add more debug logs and increase the wait-time for PD operations in restore
  * No public description
  * Add 30 second timeout to read/write from the local file system for Backint
  * No public description
  * Adds RHEL 9 VM Manager policy
  * Extract cloud-related discovery functions into separate file
  * Adding timeout to systemReplication.py command execution
  * Allow download attempts without verifying connection to bucket
  * Invoke `collectiondefinition.Start` when starting the agent in daemon mode
  * SAP Agent CLI - usability improvements for flags and help menu
  * Add host project information to HANA DB component discovery data.
  * Use proto names for default configuration during Backint installation
  * Extending logging capabilities to all packages of the agent
  * Added a feature for exposing TCP connection metrics
  * Migrating context logging logic to all packages of SAP Agent
  * Add an ifthisthenthatlint to ensure new script is kept in sync with rule proto
  * (collectiondefition) - Discard unknown fields and remove breaking metrics
  * Moving commandlineexecutor from internal to shared for sqlserveragent
  * Define startup function for collectiondefinition package
  * Check error on close of destFile in backint restore
  * Allow trailing zeros for millisecond timestamps in Backint
  * Add pid to all agent logs
  * Bump SAP Agent version to 2.7 (placeholder release version)
  * Separate collection definition validation functionality into a separate file
  * Add datetime to migration folder for Backint installation
  * Add symlink for Backint log file to install directory
  * Set a deadline for the final flush to cloud logging
  * Increase chunk retry deadline in storage package
  * Fix order dependent tests in sapagent/internal/storage
  * Change support bundle feature to collect the OTE logs from new path
  * Usage logging for remote WLM validation metrics collection from the collector instance
  * Extract discovery functions performed on the host to a separate file
  * Improve agent shutdown experience in daemon mode
  * Fix Backint restoring incorrect file
  * Google Events - rule proto initial submission
  * Move gce package to shared folder for use by SQL Server agent
  * Add GCS integration into collectiondefinition package
  * Standardize import aliases
  * go mod updates
  * Fixing go/gotsan data race error in processmetrics_test
  * Add Backint support for Inquire line: `#EBID <external_backup_id>`
  * Chown Backint install directories to user/group of the opt/ folder
  * Create OTE logs under a subdir under /var/log as /var/log is only writable by root
  * Will not create an empty log file for logusage logs and one
    time execution logs will have 0666 file mode
  * Setting the log file created to world read+write permission
  * Bump golang.org/x/net from 0.15.0 to 0.17.0
  * Add recovery_bucket parameter to Backint
  * Extract SAP related discovery functions to a separate file
  * Fix Backint install directory
  * Fix Backint parallel uploads
  * Move maintenance collector to beta API
  * Pruning batches to prevent time series duplication
  * Added a logger for incorporating service context keys in logs
  * Encode the DB password string to handle passwords with special characters
  * Handling non error scenarios better in netweaver.go
  * Internal change
  * fixes typo on backint install
  * Allow all users to execute google_cloud_sap_agent
  * Fix hdbbackint script.
  * Subdirs for Backint DIAGNOSE temporary files
  * Report zero-value metrics for upcoming maintenance
  * Clean up gcealpha functionality
  * Fix default configuration values in daemon and backint
  * Update the comment in proto to reflect that the metric
    path in skip list should start with /sap
  * Implemented separation of context of different services
* Fri Oct 20 2023 adrian.glaubitz@suse.com
- Update to version 2.6 (bsc#1215672, bsc#1215673)
  * Rolling back previous change for storing Project Number,
    Project ID is sufficient, no need to add complexity
  * Determine location of HANA global.ini using SAP system discovery logic
  * Add numeric project ID prefix to object name for ReadMetrics
  * Discovery now looks up and stores project number with discovery data
  * ReadMetrics updates for IAM permissions and bucket object names
  * fixing the bug in backoff logic, using separate policies
    for each collector and adding some logs
  * Backint migration from the old agent and supporting legacy parameters
  * adding new backoff policies for process metrics and fixing the
    bug in process metrics sapservice collector
  * Bump SAP Agent version to 2.6
  * Fix an issue where HANA hosts may not be discovered
    properly if hostname differs from instance name
  * Use Go 1.20 friendly sorting solution
  * adding retries in process metrics logic with backoffs
  * Fix parsing of instance (host/VM) name in Pacemaker pcmk_delay_max metric
  * Add the collection definition changes for the SAP HANA Topology metrics
  * Template for Cloud Monitoring Alerts for Backint errors
  * adding backoff to InstanceProperties to each collector
  * Reduced the number of parameters of startXX functions
    by consolidating them into respective structs
  * completing TODO (b/298315981): Create a map from skipped
    list metrics and pass it to collectors.
  * Proto package name changes to reflect the current path
  * Use instance_name instead of instance_id for baremetal systems
  * Decode encryption keys for Backint.
  * Moving hareplication metric to fast moving metrics
  * Added backoffs package in process metrics to keep the backoff policies
    and retry policies separately and make it reusable acrosss process metrics
  * Install Backint OTE
  * Adding skip list logic to process metrics
  * Separating fastmoving metrics into a separate file from other process metrics
  * Update remote collection to use collected instance's Cloud Properties
  * ReadMetrics upload to bucket and send status to monitoring
  * Remove local implementation of DW API in favor of using generated third_party version
  * ReadMetrics read input file and write results to local filesystem
  * Clean up command line executions to collect SAP Control metrics
  * Adding new OTE structure for ReadMetrics
  * Add the SUSE specific spec file to keep upstream changes and SUSE packaging in sync
  * Collect and report upcoming maintenance
  * Add basepath override and gcealpha functionality
  * Making proto changes for process metrics re-arch
  * Changes for generating HANA Insights locally into a markdown file
  * Delay feature specific daily action logs by 24 hours
    to avoid noise created by startup failures
  * Update to the rule "maximum_invalid_connect_attempts"
  * Add some missing related resources
  * Fix rate limiting for compression enabled uploads/downloads
  * Optional User-Agent parameter added to storage package client connection
  * Relocate gcealpha to /internal
  * Fix parse_test error
  * Retries added for opening files in Backint
  * Make processmetrics unit tests hermetic
  * Remove if-this-then-that requirement from WLM validation rule
  * Fix WriteInsight JSON encoding, and add missing elements
  * Add configuration value to change API endpoint for Data Warehouse calls
  * Storage package progress messages based off of read/writes directly to the bucket
  * Make Collect DB Metrics as NO-OP when metrics are being read from override file
  * Remove unused field from backint proto
  * Custom retries for the storage package with exponential backoff and MaxRetries setting
* Thu Aug 31 2023 adrian.glaubitz@suse.com
- Update to version 2.5
  + No upstream changelog provided
* Thu Aug 17 2023 adrian.glaubitz@suse.com
- Install missing default configuration file (bsc#1214293)
* Wed Jul 19 2023 adrian.glaubitz@suse.com
- Update to version 2.1 (bsc#1213397)
  + No upstream changelog provided
* Wed Jul 12 2023 adrian.glaubitz@suse.com
- Update to version 2.0 (bsc#1211516, bsc#1211517)
  + No upstream changelog provided
* Mon May  8 2023 adrian.glaubitz@suse.com
- Update to version 1.5.1 (bsc#1210464, bsc#1210465)
  + No upstream changelog provided
- Raise golang API version to 1.20
* Thu Feb 16 2023 rjschwei@suse.com
- Initial build (#jsc-PED-2879)
  + Version 1.0
